@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Translate lists of space separated integers (magnitude less than 62) and print 
+Translate lists of space separated integers (magnitude less than 62) and print
 as strings of alphanumeric characters. This is useful mainly for some machine
 learning algorithms that only take string input.
 
@@ -10,16 +10,17 @@ usage: %prog < int_seqs > strings
 from __future__ import print_function
 
 import sys
-from itertools import *
 
 table = "012345678ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
 
 
 def main():
     for line in sys.stdin:
-        ints = [ int( f ) for f in line.split() ]
-        if max( ints ) > len( table ):
+        ints = [int(f) for f in line.split()]
+        if max(ints) > len(table):
             raise ValueError("Alphabet size too large!")
-        print(str.join( '', [ table[i] for i in ints ] ))
+        print(str.join('', [table[i] for i in ints]))
 
-if __name__ == "__main__": main()
+
+if __name__ == "__main__":
+    main()
