@@ -9,20 +9,20 @@ TODO: This is very special case, should it be here?
 from __future__ import print_function
 
 import sys
+from collections import defaultdict
 
-counts = dict()
+counts = defaultdict(int)
 
 max_index = -1
 
 for line in sys.stdin:
     if line[0].isdigit():
-        current_index = int( line )
-        max_index = max( current_index, max_index )
+        current_index = int(line)
+        max_index = max(current_index, max_index)
     elif line[0] == "'":
-        try: counts[ current_index ] += 1
-        except: counts[ current_index ] = 1
+        counts[current_index] += 1
     else:
         raise ValueError("Invalid input line " + line)
 
-for i in range( max_index + 1 ):
-    print(counts.get( i, 0 ))
+for i in range(max_index + 1):
+    print(counts.get(i, 0))
