@@ -9,20 +9,16 @@ usage: %prog score_file out_file < wiggle_data
 """
 from __future__ import division, print_function
 
-import sys
-
 import bx.wiggle
-import psyco_full
 from bx import misc
 from bx.binned_array import BinnedArray
 from bx.cookbook import doc_optparse
-from bx_extras.fpconst import isNaN
 
 
 def main():
-    
+
     # Parse command line
-    options, args = doc_optparse.parse( __doc__ )
+    options, args = doc_optparse.parse(__doc__)
     try:
         if options.comp:
             comp_type = options.comp
@@ -30,28 +26,28 @@ def main():
             comp_type = None
         score_fname = args[0]
         out_fname = args[1]
-    except:
+    except Exception:
         doc_optparse.exit()
 
     scores = BinnedArray()
 
-    ## last_chrom = None
-    for i, ( chrom, pos, val ) in enumerate( bx.wiggle.Reader( misc.open_compressed( score_fname ) ) ):
-        #if last_chrom is None: 
+    for i, (chrom, pos, val) in enumerate(bx.wiggle.Reader(misc.open_compressed(score_fname))):
+        # if last_chrom is None:
         #    last_chrom = chrom
-        #else: 
+        # else:
         #    assert chrom == last_chrom, "This script expects a 'wiggle' input on only one chromosome"
         scores[pos] = val
         # Status
         if i % 10000 == 0:
             print(i, "scores processed")
 
-    out = open( out_fname, "w" )
+    out = open(out_fname, "w")
     if comp_type:
-        scores.to_file( out, comp_type=comp_type )
-    else:    
-        scores.to_file( out )
+        scores.to_file(out, comp_type=comp_type)
+    else:
+        scores.to_file(out)
     out.close()
 
+
 if __name__ == "__main__":
     main()
